@@ -2,7 +2,7 @@ package Spreadsheet::XLSX::Reader::LibXML::XMLReader::Worksheet;
 BEGIN {
   $Spreadsheet::XLSX::Reader::LibXML::XMLReader::Worksheet::AUTHORITY = 'cpan:JANDREW';
 }
-use version; our $VERSION = qv('v0.18.2');
+use version; our $VERSION = qv('v0.20.4');
 
 
 use	5.010;
@@ -59,6 +59,7 @@ has workbook_instance =>(
 						is_empty_the_end			_starts_at_the_edge
 						get_group_return_type		set_group_return_type
 						get_epoch_year				change_output_encoding
+						get_date_behavior			set_date_behavior
 					)],
 		handles	=> [qw(
 						counting_from_zero			boundary_flag_setting
@@ -68,6 +69,7 @@ has workbook_instance =>(
 						is_empty_the_end			_starts_at_the_edge
 						get_group_return_type		set_group_return_type
 						get_epoch_year				change_output_encoding
+						get_date_behavior			set_date_behavior
 					)],
 		required => 1,
 	);
@@ -639,6 +641,12 @@ See the SYNOPSIS in L<Spreadsheet::XLSX::Reader::LibXML>
     
 =head1 DESCRIPTION
 
+B<This documentation is written to explain ways to extend this package.  To use the data 
+extraction of Excel workbooks, worksheets, and cells please review the documentation for  
+L<Spreadsheet::XLSX::Reader::LibXML>,
+L<Spreadsheet::XLSX::Reader::LibXML::Worksheet>, and 
+L<Spreadsheet::XLSX::Reader::LibXML::Cell>>
+
 POD not written yet!
 
 =head1 SUPPORT
